package com.zanxiang.manage.service.Impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fasterxml.jackson.databind.util.JSONPObject;
import com.zanxiang.common.enums.DeleteEnum;
import com.zanxiang.common.enums.PayDeviceEnum;
import com.zanxiang.common.utils.StringUtils;
import com.zanxiang.common.utils.bean.BeanUtils;
import com.zanxiang.manage.domain.bo.PayMerchantBO;
import com.zanxiang.manage.domain.bo.PayWayExtBO;
import com.zanxiang.manage.domain.dto.PayMerchantDTO;
import com.zanxiang.manage.domain.params.PayMerchantListParam;
import com.zanxiang.manage.domain.vo.PayMerchantListVO;
import com.zanxiang.manage.service.PayMerchantService;
import com.zanxiang.manage.service.PayWayService;
import com.zanxiang.mybatis.entity.PayMerchant;
import com.zanxiang.mybatis.entity.PayWay;
import com.zanxiang.mybatis.mapper.PayMerchantMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * 游戏支付商户配置表 服务实现类
 *
 * @author xufeng
 * @date 2022-06-16 19:04
 */
@Service
public class PayMerchantServiceImpl extends ServiceImpl<PayMerchantMapper, PayMerchant> implements PayMerchantService {

    @Autowired
    private PayWayService payWayService;


    @Override
    public PayMerchantDTO info(Long id) {
        PayMerchant data = getOne(new LambdaQueryWrapper<PayMerchant>().eq(PayMerchant::getId, id).eq(PayMerchant::getIsDelete, DeleteEnum.NO.getCode()));
        if (data == null) {
            return null;
        }
        return BeanUtils.copy(data, PayMerchantDTO.class);
    }

    public Boolean saveOrUpdate(PayMerchantBO bo) {
        PayMerchant data = BeanUtils.copy(bo, PayMerchant.class);
        //删除时候增加删除时间
        if (data.getIsDelete() != null && data.getIsDelete() == DeleteEnum.YES.getCode()) {
            data.setDeleteTime(new Date());
        }
        if (!StringUtils.isEmpty(data.getPayDevice())) {
            data.setPayDevice("," + data.getPayDevice().trim() + ",");
        }
        return saveOrUpdate(BeanUtils.copy(data, PayMerchant.class));
    }

    @Override
    public IPage<PayMerchantListVO> list(PayMerchantListParam bo) {
        PayMerchant app = BeanUtils.copy(bo, PayMerchant.class);
        IPage<PayMerchantListVO> convert = page(bo.toPage(), new QueryWrapper<PayMerchant>().lambda().setEntity(app)).convert(this::toVo);
        if (convert == null) {
            return null;
        }
        List<PayWay> list = payWayService.list(new LambdaQueryWrapper<PayWay>().eq(PayWay::getParentId, 0));
        Map<Integer, PayWay> payWayMap = list.stream().collect(Collectors.toMap(PayWay::getId, PayWay -> PayWay));
        convert.getRecords().forEach(t -> {
            PayWay payWayInfo = payWayMap.get(t.getPayWayId());
            if (t.getPayWayId() == null || payWayInfo == null) {
                return;
            }
            //PayWayExtBO payExt = JSONObject.parseObject(payWayInfo.getPayExt(), PayWayExtBO.class);
            t.setPayWayName(payWayInfo.getPayName());
            t.setPayDeviceName(PayDeviceEnum.getDesc(t.getPayDevice()));
        });
        return convert;
    }


    private PayMerchantListVO toVo(PayMerchant payMerchant) {
        if (Objects.isNull(payMerchant)) {
            return null;
        }
        return BeanUtils.copy(payMerchant, PayMerchantListVO.class);
    }

//    @Override
//    public Boolean config(PayMerchantBO bo) {
//        PayMerchantDTO info = info(bo.getId());
//        if (info == null) {
//            return null;
//        }
//        return null;
//    }
}
